searchData={"items":[{"type":"module","title":"KeyDiff","doc":"Provides a single function, `diff/3` for comparing two maps.","ref":"KeyDiff.html"},{"type":"module","title":"Lists - KeyDiff","doc":"List diff is not implemented, and lists are treated like any single value of a key.\nIf any key value is a list and the list contents change, then this is reflected in the `updates` list\nof the return tuple as a path to the key. The contents of the items in the list are not diffed.\n\nIn order to work around this limitation, it is advised to turn lists into mapped representations -\nespecially where the items in the list are maps that can be uniquely identified by one of their keys.\n\nFor example:\n\n    a = %{\"key_a\" => [%{\"id\": 1}, %{\"id\": 2}, %{\"id\": 3}]}\n\nshould first be transformed into the following map:\n\n    a = %{\"key_a\" => %{1 => %{\"id\": 1}, 2 => %{\"id\": 2}, 3 => %{\"id\": 3}}}\n\nThis way, `a` can now be used with `diff/3` and it will look for changes in the maps under the `\"key_a\"` key value.","ref":"KeyDiff.html#module-lists"},{"type":"function","title":"KeyDiff.diff/3","doc":"Compares two maps/structs and returns a tuple of lists containing differences between the two maps.\n\nThe returning result is a tuple containing 3 lists:\n\n  list of additions - a list of keys new in the map\n  list of deletions - a list of keys removed from the previous map\n  list of updates - list of keys that had their values modified","ref":"KeyDiff.html#diff/3"},{"type":"function","title":"Options - KeyDiff.diff/3","doc":"- `depth` _(default: `nil`)_, an integer that will stop the diffing at the specified level of depth\n    in the map; it will recurse into the map only `depth` number of times. If not set or `nil` then\n    it will process the entire map tree.\n\nThis is useful in quickly determining changes in `depth` number of levels, instead of having the entire\nstructure processed.","ref":"KeyDiff.html#diff/3-options"},{"type":"function","title":"Examples - KeyDiff.diff/3","doc":"# No differences between the two maps\n    iex> KeyDiff.diff(%{a: 1}, %{a: 1})\n    {[], [], []}\n\n    # Top-level key is changed.\n    iex> KeyDiff.diff(%{a: 1}, %{a: 2})\n    {[], [], [:a]}\n\n    # Top level key `:a` is removed and key `:b` is added\n    iex> KeyDiff.diff(%{a: 1}, %{b: 2})\n    {[:b], [:a], []}\n\n    # Second level key `:b` is removed and second level key `:c` is modified\n    # `[:a, [:b]]` represents the top-level key `:a` under which keys `[:b]` are removed\n    # from.\n    # `[:a, [:c]]` represent the top-level key `:a` under which keys `[:c]` are changed.\n    iex> KeyDiff.diff(%{a: %{b: \"b\", c: \"c\"}}, %{a: %{c: \"d\"}})\n    {[], [[:a, [:b]]], [[:a, [:c]]]}","ref":"KeyDiff.html#diff/3-examples"},{"type":"type","title":"KeyDiff.key/0","doc":"","ref":"KeyDiff.html#t:key/0"},{"type":"type","title":"KeyDiff.key_path/0","doc":"","ref":"KeyDiff.html#t:key_path/0"}],"content_type":"text/markdown"}